##
##  apache-wsgi.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2016 OpenPKG Foundation e.V. <http://openpkg.net/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         apache-wsgi
Summary:      Apache Extension: Python WSGI Support
URL:          http://www.modwsgi.org/
Vendor:       Graham Dumpleton
Packager:     OpenPKG Foundation e.V.
Distribution: OpenPKG Community
Class:        EVAL
Group:        Web
License:      Apache
Version:      3.4
Release:      20160501

#   list of sources
Source0:      http://modwsgi.googlecode.com/files/mod_wsgi-%{version}.tar.gz
Source1:      apache-wsgi.conf

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20100101, flex
PreReq:       OpenPKG, openpkg >= 20100101
BuildPreReq:  apache, python
PreReq:       apache, python

%description
    The mod_wsgi adapter is an Apache module that provides a WSGI
    compliant interface for hosting Python based web applications within
    Apache. The adapter is written completely in C code against the
    Apache C runtime and for hosting WSGI applications within Apache has
    a lower overhead than using existing WSGI adapters for mod_python or
    CGI.

%track
    prog apache-wsgi = {
        version   = %{version}
        url       = http://code.google.com/p/modwsgi/downloads/list
        regex     = mod_wsgi-(__VER__)\.tgz
    }

%prep
    %setup -q -n mod_wsgi-%{version}

%build
    export CC="%{l_cc}"
    export CFLAGS="%{l_cflags -O}"
    export CPPFLAGS="%{l_cppflags}"
    export LDFLAGS="%{l_ldflags}"
    case "%{l_platform -t}" in
        *-freebsd* )
            CFLAGS="$CFLAGS -pthread"
            LDFLAGS="$LDFLAGS -pthread -lpthread"
            ;;
    esac
    ./configure \
        --prefix=%{l_prefix} \
        --with-apxs=%{l_prefix}/sbin/apxs \
        --with-python=%{l_prefix}/bin/python
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install DESTDIR=$RPM_BUILD_ROOT

    #   install default configuration file
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/apache/apache.d
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE apache-wsgi.conf} $RPM_BUILD_ROOT%{l_prefix}/etc/apache/apache.d/

    #   create run-time directory
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/var/apache-wsgi

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%attr(-,%{l_nusr},%{l_ngrp}) %{l_prefix}/var/apache-wsgi' \
        '%config %{l_prefix}/etc/apache/apache.d/apache-wsgi.conf'

%files -f files

%clean

%post
    #   after upgrade, restart service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} apache status 2>/dev/null`
    [ ".$apache_active" = .yes ] && %{l_rc} apache restart
    exit 0

